<?php
/**
 * Dynamic CSS for the frontend.
 *
 * @package Outspoken
 */

defined( 'WPINC' ) || exit;

/**
 * Helper function.
 * Merge and combine the CSS elements.
 *
 * @param  string|array $elements An array of our elements.
 *                                If we use a string then it is directly returned.
 * @return string
 */
function outspoken_implode( $elements = array() ) {

	if ( ! is_array( $elements ) ) {
		return $elements;
	}

	// Make sure our values are unique.
	$elements = array_unique( $elements );

	// Sort elements alphabetically.
	// This way all duplicate items will be merged in the final CSS array.
	sort( $elements );

	// Implode items and return the value.
	return implode( ',', $elements );

}

/**
 * Maps elements from dynamic css to the selector.
 *
 * @param  array  $elements The elements.
 * @param  string $selector The selector.
 * @return array
 */
function outspoken_map_selector( $elements, $selector ) {
	$array = array();

	foreach ( $elements as $element ) {
		$array[] = $element . $selector;
	}

	return $array;
}

/**
 * Map CSS selectors from values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function outspoken_map_css_selectors( &$css, $values ) {
	if ( isset( $values['css-selectors'] ) ) {
		$elements = $values['css-selectors'];
		unset( $values['css-selectors'] );

		$css[ $elements ] = $values;
	}
}

/**
 * Merge CSS values.
 *
 * @param array $css    Array of dynamic CSS.
 * @param array $values Array of values.
 */
function outspoken_merge_value( &$css, $values ) {
	foreach ( $values as $id => $val ) {
		$css[ $id ] = $val;
	}
}

/**
 * Format of the $css array:
 * $css['media-query']['element']['property'] = value
 *
 * If no media query is required then set it to 'global'
 *
 * If we want to add multiple values for the same property then we have to make it an array like this:
 * $css[media-query][element]['property'][] = value1
 * $css[media-query][element]['property'][] = value2
 *
 * Multiple values defined as an array above will be parsed separately.
 */
function outspoken_dynamic_css_array() {

	global $wp_version;

	$css       = array();
	$c_page_id = outspoken()->get_page_id();

	// Site Background.
	$css['global']['html body'] = Outspoken_Sanitize::background( outspoken_get_settings( 'mts_background' ) );

	// Top bar Background.
	$css['global']['.top-bar'] = Outspoken_Sanitize::background( outspoken_get_settings( 'top_bar_background' ) );

	// Header Background.
	$css['global']['.main-header, #header.sticky-navigation-active, .navigation ul ul'] = Outspoken_Sanitize::background( outspoken_get_settings( 'header_background' ) );

	// Logo Font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'outspoken_logo' ) ) );
	// Primary Navigation font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'primary_navigation_font' ) ) );
	// Content Font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'content_font' ) ) );
	// Read more Font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'readmore_font' ) ) );
	// Pagination.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'pagination_font' ) ) );
	// Breadcrumbs font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'breadcrumb_font' ) ) );
	// Single post title font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'single_title_font' ) ) );
	// Single Page titles font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'single_page_titles_font' ) ) );
	// Single subscribe box.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'single_subscribe_title_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'single_subscribe_text_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'single_subscribe_input_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'single_subscribe_submit_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'single_subscribe_small_text_font' ) ) );
	// Author Box.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'authorbox_title_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'authorbox_author_name_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'authorbox_text_font' ) ) );
	// Footer Nav.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'footer_nav_font' ) ) );
	// Sidebar widget title font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'sidebar_title_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'sidebar_buttons_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'submit_button_font' ) ) );
	// Sidebar widget font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'mts_widget_links' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'default_widget_links' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'sidebar_url_bigthumb' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'sidebar_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'sidebar_font_bigthumb' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'sidebar_postinfo_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'sidebar_postinfo_font_bigthumb' ) ) );
	// Tab widget title font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'tabs_title_font' ) ) );
	// Footer widget title font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'footer_outspoken_logo' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'top_footer_title_font' ) ) );
	// Footer link font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'top_footer_link_font' ) ) );
	// Footer MTS link font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'mts_footer_widget_links' ) ) );
	// Footer widget font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'top_footer_font' ) ) );
	// Copyrights section font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'copyrights_font' ) ) );
	// Fields font.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'fields_font' ) ) );
	// H1 title in the content.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'h1_headline' ) ) );
	// H2 title in the content.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'h2_headline' ) ) );
	// H3 title in the content.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'h3_headline' ) ) );
	// H4 title in the content.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'h4_headline' ) ) );
	// H5 title in the content.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'h5_headline' ) ) );
	// H6 title in the content.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'h6_headline' ) ) );

	// Footer background.
	$css['global']['#site-footer'] = Outspoken_Sanitize::background( outspoken_get_settings( 'mts_footer_background' ) );
	// Copyrights background.
	$css['global']['.copyrights'] = Outspoken_Sanitize::background( outspoken_get_settings( 'mts_copyrights_background' ) );

	outspoken_dynamic_css_skin( $css );
	outspoken_sidebar_position( $css );
	outspoken_header( $css );
	outspoken_sidebar_styling( $css );
	outspoken_post_layouts( $css );
	outspoken_post_pagination( $css );
	outspoken_footer( $css );
	outspoken_copyrights( $css );
	outspoken_single( $css );
	outspoken_single_social_buttons( $css );
	outspoken_archive_post( $css );
	outspoken_misc_css( $css );

	return apply_filters( 'outspoken_dynamic_css_array', $css );
}

/**
 * Skin CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_dynamic_css_skin( &$css ) {

	// Colors.
	$primary_color_scheme = Outspoken_Sanitize::color( outspoken_get_settings( 'primary_color_scheme' ) );

	// Text Color.
	$elements = array(
		'a',
		'body a:hover',
		'.reply a',
		'.latestPost .title a:hover',
		'.related-posts .title a:hover',
		'.layout-default .latestPost .title a:hover',
		'.layout-1 .latestPost .title a:hover',
		'.layout-1 .latestPost.small .title a:hover',
		'.layout-2 .latestPost.large .title a:hover',
		'.layout-2 .latestPost.small .title a:hover',
		'.woocommerce ul.products li.product .price',
		'.product_list_widget .amount',
		'.woocommerce div.product p.price, .woocommerce div.product span.price',
		'.shareit-circular.standard .fa:hover',
		'.textwidget a',
		'#wp-calendar td#today',
		'.pnavigation2 a',
		'#sidebar .widget li a:hover',
		'.title a:hover',
		'#sidebar .widget li.horizontal-small .post-title a:hover',
		'#tabber .inside li a:hover',
		'.fn a',
		'.widget .wp_review_tab_widget_content a',
		'.sidebar .wpt_widget_content a',
		'.related-posts .title a:hover',
		'blockquote:after',
		'article ul li::before',
		'.single .pagination a .current:hover',
		'blockquote::before',
		'.postauthor h5 a:hover',
		'#primary-navigation li a:hover',
		'#sidebar .widget .vertical-small .widget-readmore a',
		'.related-readmore a',
		'.toggle-menu .toggle-caret .fa',
		'#primary-navigation li.current-menu-item a',
		'.layout-grid .latestPost .title a:hover',
		'.tags a',
		'.tagcloud a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.widget .sbutton',
		'#sidebar .widget .post-info .thecategory a',
		'.shareit-circular.standard .share-text',
		'.widget #wp-subscribe input.submit',
		'.single_post .post-info a:hover',
		'a#pull:hover',
		'.header-layout2 a#pull',
		'.single-author-posts h3.title a:hover',
		'.f-widget .widget li.horizontal-small .post-title a:hover',
	);

	$css['global'][ outspoken_implode( $elements ) ]['color'] = $primary_color_scheme;
	$css['global']['#sidebar .widget a:hover']['color']       = $primary_color_scheme;
	//social svg hover color
	$css['global']['.shareit-circular.standard svg:hover']['fill'] = $primary_color_scheme;

	// Text Color Important.
	$elements = array(
		'.widget .review_thumb_large .review-result',
		'.widget .review_thumb_large .review-total-only.large-thumb',
		'.review-total-only.small-thumb .review-result-wrapper i',
		'.latestPost .post-info a:hover',
		'#sidebar .social-profile-icons ul li a:hover',
	);
	$css['global'][ outspoken_implode( $elements ) ]['color'] = $primary_color_scheme . '!important';

	// Background Color.
	$elements = array(
		'.pace .pace-progress',
		'#mobile-menu-wrapper ul li a:hover',
		'.pagination a:hover',
		'.single .pagination a:hover .current',
		'.navigation #wpmm-megamenu .wpmm-pagination a',
		'.wpmm-megamenu-showing.wpmm-light-scheme',
		'.widget_product_search button[type="submit"]:hover',
		'.widget #wp-subscribe input.submit:hover',
		'#move-to-top:hover',
		'#tabber ul.tabs li a.selected',
		'.navigation ul .sfHover a',
		'.widget-slider .slide-caption',
		'.owl-prev:hover, .owl-next:hover',
		'.widget .wp-subscribe-wrap h4.title span.decor:after',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce .bypostauthor:after',
		'.woocommerce a.button',
		'.woocommerce-page a.button',
		'.woocommerce button.button',
		'.woocommerce-page button.button',
		'.woocommerce input.button',
		'.woocommerce-page input.button',
		'.woocommerce #respond input#submit',
		'.woocommerce-page #respond input#submit',
		'.woocommerce #content input.button',
		'.woocommerce-page #content input.button',
		'.woocommerce #respond input#submit.alt.disabled',
		'.woocommerce #respond input#submit.alt.disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled',
		'.woocommerce #respond input#submit.alt:disabled:hover',
		'.woocommerce #respond input#submit.alt:disabled[disabled]',
		'.woocommerce #respond input#submit.alt:disabled[disabled]:hover',
		'.woocommerce a.button.alt.disabled, .woocommerce a.button.alt.disabled:hover',
		'.woocommerce a.button.alt:disabled',
		'.woocommerce a.button.alt:disabled:hover',
		'.woocommerce a.button.alt:disabled[disabled]',
		'.woocommerce a.button.alt:disabled[disabled]:hover',
		'.woocommerce button.button.alt.disabled',
		'.woocommerce button.button.alt.disabled:hover',
		'.woocommerce button.button.alt:disabled',
		'.woocommerce button.button.alt:disabled:hover',
		'.woocommerce button.button.alt:disabled[disabled]',
		'.woocommerce button.button.alt:disabled[disabled]:hover',
		'.woocommerce input.button.alt.disabled',
		'.woocommerce input.button.alt.disabled:hover',
		'.woocommerce input.button.alt:disabled',
		'.woocommerce input.button.alt:disabled:hover',
		'.woocommerce input.button.alt:disabled[disabled]',
		'.woocommerce input.button.alt:disabled[disabled]:hover',
		'#wpmm-megamenu .review-total-only',
		'#searchsubmit',
		'#add_payment_method .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-cart .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce-checkout .wc-proceed-to-checkout a.checkout-button',
		'.woocommerce #respond input#submit.alt',
		'.woocommerce a.button.alt',
		'.woocommerce button.button.alt',
		'.woocommerce input.button.alt',
		'.woocommerce-account .woocommerce-MyAccount-navigation li.is-active',
		'.woocommerce .woocommerce-widget-layered-nav-dropdown__submit',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-handle',
		'.woocommerce .widget_price_filter .ui-slider .ui-slider-range',
		'.woocommerce nav.woocommerce-pagination ul li a:focus',
		'.woocommerce nav.woocommerce-pagination ul li a:hover',
		'.woocommerce nav.woocommerce-pagination ul li span.current',
		'.latestPost-review-wrapper',
		'.latestPost .review-type-circle.latestPost-review-wrapper',
		'.woocommerce span.onsale',
		'.widget .widget_wp_review_tab .review-total-only.large-thumb',
		'#sidebar .widget h3::before',
		'.button:hover',
		'.breadcrumb .separator',
		'.post-info > span::after',
		'#wp-calendar caption',
		'.button',
		'.instagram-button a',
		'.widget_product_search button[type="submit"]',
		'.tags a:hover',
		'.single-subscribe .widget #wp-subscribe input.submit:hover',
		'.error404 .article .sbutton',
		'.search .article .sbutton',
		'#commentform input#submit',
		'#mtscontact_submit',
		'#sidebar .widget .tagcloud a:hover',
		'.f-widget .tagcloud a:hover',
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover',
		'.widget .wp_review_tab_widget_content ul.wp-review-tabs li.selected a::before',
		'.widget .wpt_widget_content ul.wpt-tabs li.selected a::before',
	);

	$css['global'][ outspoken_implode( $elements ) ]['background-color'] = $primary_color_scheme;

	$css['@media screen and (max-width: 865px)']['.navigation.mobile-menu-wrapper']['background-color'] = $primary_color_scheme;

	// Background Color Important.
	$elements = array(
		'.widget .wpt_widget_content #tags-tab-content ul li a:hover ',
	);
	$css['global'][ outspoken_implode( $elements ) ]['background-color'] = $primary_color_scheme . '!important';

	// Border Color.
	$elements = array(
		'.page-numbers.current',
		'.pagination a:hover',
		'.tags a:hover',
		'.tags a',
		'.tagcloud a',
		'.widget .wpt_widget_content #tags-tab-content ul li a',
		'.widget #wp-subscribe input.submit',
	);

	$css['global'][ outspoken_implode( $elements ) ]['border-color'] = $primary_color_scheme;

}

/**
 * Sidebar Position
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_sidebar_position( &$css ) {

	// Sidebar position.
	$sidebar_position = outspoken_get_settings( 'mts_layout' );

	$sidebar_metabox_location = '';
	if ( is_page() || is_single() ) {
		$sidebar_metabox_location = get_post_meta( get_the_ID(), '_mts_sidebar_location', true );
	}

	if ( 'right' !== $sidebar_metabox_location && ( 'sclayout' === $sidebar_position || 'left' === $sidebar_metabox_location ) ) {
		$css['global']['.article']['float']                = 'right';
		$css['global']['.sidebar.c-4-12']['float']         = 'left';
		$css['global']['.sidebar.c-4-12']['padding-right'] = 0;

		if ( null !== outspoken_get_settings( 'mts_social_button_position' ) && 'floating' === outspoken_get_settings( 'mts_social_button_position' ) ) {

			$shareit_class = array(
				'.right .shareit.shareit-default.floating',
				'.right .shareit.standard.floating',
				'.right .shareit.shareit-circular.floating',
			);

			$css['global'][ outspoken_implode( $shareit_class ) ]['left']  = 'auto';
			$css['global'][ outspoken_implode( $shareit_class ) ]['right'] = '0px';

			$css['global'][ outspoken_implode( $shareit_class ) ]['margin-left']  = '0px';
			$css['global'][ outspoken_implode( $shareit_class ) ]['margin-right'] = '50px';
		}
	}
	if ( 'mts_nosidebar' == mts_custom_sidebar() ) {
		$css['global']['.single-full-header']['width'] = '100%';
	}
}

/**
 * Header
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_header( &$css ) {

	$header_styles = outspoken_get_settings( 'header_styles' );
	$header_icons  = outspoken_get_settings( 'header_social_icons' );

	// Header.
	$header_class = array(
		'#header',
	);
	outspoken_merge_value( $css['global'][ outspoken_implode( $header_class ) ], Outspoken_Sanitize::margin( outspoken_get_settings( 'header_margin' ) ) );
	outspoken_merge_value( $css['global'][ outspoken_implode( $header_class ) ], Outspoken_Sanitize::padding( outspoken_get_settings( 'header_padding' ) ) );

	// Header Border.
	$header_border = Outspoken_Sanitize::border( outspoken_get_settings( 'header_border' ) );
	$css['global'][ outspoken_implode( $header_class ) ][ $header_border['direction'] ] = $header_border ['value'];

	// Nav styling.
	// Nav color.
	$css['global']['#primary-navigation .navigation ul ul a']['color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'main_navigation_dropdown_color' ) );

	$css['global']['#primary-navigation .navigation ul ul a:hover']['color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'main_navigation_dropdown_hover_color' ) );

	// Nav Background.
	if ( 'header-default' === $header_styles ) {
		$css['global']['#primary-navigation'] = Outspoken_Sanitize::background( outspoken_get_settings( 'nav_background' ) );
	}

	// Nav Padding.
	outspoken_merge_value( $css['global']['#primary-navigation'], Outspoken_Sanitize::padding( outspoken_get_settings( 'header_nav_padding' ) ) );

	// Header date.
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'header_date_font' ) ) );

	// Social icons.
	if ( 'header-default' === $header_styles && ! empty( $header_icons ) && is_array( $header_icons ) ) :
		foreach ( $header_icons as $header_icon ) :

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['background-color'] = Outspoken_Sanitize::color( $header_icon['header_icon_bgcolor'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['background-color'] = Outspoken_Sanitize::color( $header_icon['header_icon_hover_bgcolor'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['color'] = Outspoken_Sanitize::color( $header_icon['header_icon_color'] );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] . ':hover' ]['color'] = Outspoken_Sanitize::color( $header_icon['header_icon_hover_color'] );

			outspoken_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Outspoken_Sanitize::margin( $header_icon['header_icon_margin'] ) );

			outspoken_merge_value( $css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ], Outspoken_Sanitize::padding( $header_icon['header_icon_padding'] ) );

			$css['global'][ '.header-social-icons a.header-' . $header_icon['header_icon'] ]['border-radius'] = Outspoken_Sanitize::size( $header_icon['header_icon_border_radius'] . 'px' );

		endforeach;
	endif;

	// Header Ad.
	outspoken_merge_value( $css['global']['.widget-header, .small-header .widget-header'], Outspoken_Sanitize::margin( outspoken_get_settings( 'mts_header_adcode_margin' ) ) );

	// Ad-Blocker.
	$css['global']['.navigation-banner']['background'] = Outspoken_Sanitize::color( outspoken_get_settings( 'navigation_ad_background' ) );
}

/**
 * Social Share Styling
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_single_social_buttons( &$css ) {

	// Social share.
	$css['global']['.shareit.floating'] = Outspoken_Sanitize::background( outspoken_get_settings( 'social_styling_background' ) );
	outspoken_merge_value( $css['global']['.shareit.floating'], Outspoken_Sanitize::margin( outspoken_get_settings( 'social_styling_margin' ) ) );

	// Social share border.
	$social_border = Outspoken_Sanitize::border( outspoken_get_settings( 'social_styling_border' ) );
	$css['global']['.shareit.floating'][ $social_border ['direction'] ] = $social_border ['value'];

	$social_button_layout   = outspoken_get_settings( 'social_button_layout' );
	$social_button_position = outspoken_get_settings( 'social_floating_button_position' );
	if ( 'default' === $social_button_layout ) {
		$share_class = '.shareit.shareit-' . $social_button_layout . '.floating';
	} else {
		$share_class = '.shareit.' . $social_button_layout . '.floating';
	}
	if ( ! empty( $social_button_position ) && is_array( $social_button_position ) ) {
		foreach ( $social_button_position as $key => $position ) {
			$css['global'][ $share_class ][ $key ] = $position;
		}
	}
}

/**
 * Sidebar styling
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_sidebar_styling( &$css ) {

	// Sidebar.
	outspoken_merge_value( $css['global']['.widget, .f-widget .widget'], Outspoken_Sanitize::background( outspoken_get_settings( 'sidebar_styling_background' ) ) );
	outspoken_merge_value( $css['global']['.widget, .f-widget .widget'], Outspoken_Sanitize::margin( outspoken_get_settings( 'sidebar_styling_margin' ) ) );
	outspoken_merge_value( $css['global']['.widget, .f-widget .widget'], Outspoken_Sanitize::padding( outspoken_get_settings( 'sidebar_styling_padding' ) ) );

	// Sidebar border.
	$sidebar_border = Outspoken_Sanitize::border( outspoken_get_settings( 'sidebar_styling_border' ) );
	$css['global']['.widget, .f-widget .widget'][ $sidebar_border['direction'] ] = $sidebar_border['value'];

	// Sidebar title.
	$sidebar_title                   = '#sidebar .widget h3';
	$css['global'][ $sidebar_title ] = Outspoken_Sanitize::background( outspoken_get_settings( 'sidebar_title_styling_background' ) );
	outspoken_merge_value( $css['global'][ $sidebar_title ], Outspoken_Sanitize::padding( outspoken_get_settings( 'sidebar_title_styling_padding' ) ) );
	outspoken_merge_value( $css['global'][ $sidebar_title ], Outspoken_Sanitize::margin( outspoken_get_settings( 'sidebar_title_styling_margin' ) ) );

	// Sidebar Title border.
	$sidebar_title_border = Outspoken_Sanitize::border( outspoken_get_settings( 'widget_title_border' ) );
	$css['global'][ $sidebar_title ][ $sidebar_title_border['direction'] ] = $sidebar_title_border['value'];

}

/**
 * Layout CSS
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_post_layouts( &$css ) {

	// Post Layouts.
	$features = outspoken_get_settings( 'featured_categories' );
	foreach ( $features as $feature ) :

		if ( ! isset( $feature['unique_id'] ) ) {
			continue;
		}

		$category     = $feature['mts_featured_category'];
		$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : 'layout-default';
		$unique_id    = $feature['unique_id'];

		if ( 'layout-default' === $posts_layout ) :
			$posts_layout = 'default';
		endif;

		// Section title align.
		$post_title_align = outspoken_get_settings( 'post_title_alignment_' . $unique_id );

		// Post area.
		$cat_class = 'cat-latest';
		if ( 'latest' !== $category ) {
			$category  = get_term_by( 'slug', $category, 'category' );
			$cat_class = sanitize_key( ! empty( $category ) ? $category->name : '' );
		}

		$title_class = '.title-container.title-id-' . $unique_id . ' h3';

		$css['global'][ $title_class ] = Outspoken_Sanitize::background( outspoken_get_settings( 'featured_category_title_background_' . $unique_id ) );
		outspoken_merge_value( $css['global'][ $title_class ], Outspoken_Sanitize::margin( outspoken_get_settings( 'featured_category_title_margin_' . $unique_id ) ) );
		outspoken_merge_value( $css['global'][ $title_class ], Outspoken_Sanitize::padding( outspoken_get_settings( 'featured_category_title_padding_' . $unique_id ) ) );
		// Section title border.
		$post_title_border = Outspoken_Sanitize::border( outspoken_get_settings( 'post_title_border_' . $unique_id ) );
		$css['global'][ $title_class ][ $post_title_border['direction'] ] = $post_title_border['value'];

		// Title alignment.
		$align_class = '.title-container.title-id-' . $unique_id;
		if ( 'center' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align'] = 'center';
		elseif ( 'right' === $post_title_align ) :
			$css['global'][ $align_class ]['text-align']              = 'right';
			$css['global'][ $align_class . ' + .view-more' ]['left']  = '0';
			$css['global'][ $align_class . ' + .view-more' ]['right'] = 'auto';
		endif;

		outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'featured_category_title_font_' . $unique_id ) ) );

		if ( 'layout-default' === $posts_layout ) {
			$post_class = '.layout-' . $unique_id . '.default-container';
		} else {
			$post_class = '.layout-' . $unique_id;
		}

		// Post border.
		$post_border = Outspoken_Sanitize::border( outspoken_get_settings( 'post_border_' . $unique_id ) );
		$css['global'][ $post_class ][ $post_border['direction'] ] = $post_border['value'];

		/**
		 * Meta info
		 */
		outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'post_categories_font_' . $unique_id ) ) );
		outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'meta_info_font_' . $unique_id ) ) );

		outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'post_title_font_' . $unique_id ) ) );
		outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'post_excerpt_font_' . $unique_id ) ) );

		if ( 'layout-1' === $posts_layout || 'layout-2' === $posts_layout ) {
			outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'post_small_title_font_' . $unique_id ) ) );
		}

		// Border.
		$meta_info_border = Outspoken_Sanitize::border( outspoken_get_settings( 'meta_info_border_' . $unique_id ) );
		$css['global'][ '.layout-' . $unique_id . ' .latestPost .post-info' ][ $meta_info_border['direction'] ] = $meta_info_border['value'];

		// All Posts Margin and Padding.
		outspoken_merge_value( $css['global'][ $post_class ], Outspoken_Sanitize::margin( outspoken_get_settings( 'post_margin_' . $unique_id ) ) );
		outspoken_merge_value( $css['global'][ $post_class ], Outspoken_Sanitize::padding( outspoken_get_settings( 'post_padding_' . $unique_id ) ) );

	endforeach;
}

/**
 * Pagination
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_post_pagination( &$css ) {

	// Pagination Active class.
	$pagination_class_active = array(
		'.pace .pace-progress',
		'.page-numbers.current',
		'#mobile-menu-wrapper ul li a:hover',
		'.pagination a:hover',
	);
	$pagination_class        = array(
		'.pagination a',
		'.single .pagination > .current .currenttext',
		'.pagination .page-numbers.dots',
	);
	outspoken_merge_value( $css['global'][ outspoken_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Outspoken_Sanitize::margin( outspoken_get_settings( 'mts_pagenavigation_margin' ) ) );
	if ( '2' !== outspoken_get_settings( 'mts_pagenavigation_type' ) ) {
		$css['global'][ outspoken_implode( $pagination_class ) ]['background-color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'mts_pagenavigation_bgcolor' ) );

		$css['global'][ outspoken_implode( $pagination_class_active ) ]['background-color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'mts_pagenavigation_hover_bgcolor' ) );

		$css['global'][ outspoken_implode( $pagination_class ) ]['color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'mts_pagenavigation_color' ) );

		$css['global'][ outspoken_implode( $pagination_class_active ) ]['color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'mts_pagenavigation_hover_color' ) );

		outspoken_merge_value( $css['global'][ outspoken_implode( array_merge( $pagination_class_active, $pagination_class ) ) ], Outspoken_Sanitize::padding( outspoken_get_settings( 'mts_pagenavigation_padding' ) ) );
	} else {
		$css['global']['#load-posts a']['background-color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'load_more_bgcolor' ) );

		$css['global']['#load-posts a:hover']['background-color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'load_more_hover_bgcolor' ) );

		$css['global']['#load-posts a']['color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'load_more_color' ) );

		$css['global']['#load-posts a:hover']['color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'load_more_hover_color' ) );

		outspoken_merge_value( $css['global']['#load-posts a'], Outspoken_Sanitize::padding( outspoken_get_settings( 'load_more_padding' ) ) );
	}

	$border_radius_class   = $pagination_class;
	$border_radius_class[] = '#load-posts a';

	// Border radius.
	$css['global'][ outspoken_implode( $border_radius_class ) ]['border-radius'] = Outspoken_Sanitize::size( outspoken_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	$css['global'][ outspoken_implode( $pagination_class_active ) ]['border-radius'] = Outspoken_Sanitize::size( outspoken_get_settings( 'mts_pagenavigation_border_radius' ) . 'px' );

	// Pagination border.
	$pagination_border = Outspoken_Sanitize::border( outspoken_get_settings( 'pagenavigation_border' ) );
	$css['global'][ outspoken_implode( $pagination_class ) ][ $pagination_border ['direction'] ] = $pagination_border ['value'];

	// Pagination Alignment.
	$pagenavigation_align = outspoken_get_settings( 'pagenavigation_alignment' );
	if ( 'left' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'left';
	elseif ( 'right' === $pagenavigation_align ) :
		$css['global']['.pagination']['text-align'] = 'right';
	endif;

	// Load more Alignment.
	$load_more_align = outspoken_get_settings( 'load_more_alignment' );
	if ( 'left' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'left';
	elseif ( 'right' === $load_more_align ) :
		$css['global']['#load-posts']['text-align'] = 'right';
	elseif ( 'full' === $load_more_align ) :
		$css['global']['#load-posts a']['width'] = '100%';
	endif;
}

/**
 * Single
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_single( &$css ) {

	// Single Page auto padding.
	$single_padding = Outspoken_Sanitize::padding( outspoken_get_settings( 'mts_single_styling_padding' ) );

	$css['global']['.single-featured-wrap']['margin-top']   = '-' . $single_padding['padding-top'];
	$css['global']['.single-featured-wrap']['margin-right'] = '-' . $single_padding['padding-right'];
	$css['global']['.single-featured-wrap']['margin-left']  = '-' . $single_padding['padding-left'];

	// Single, Page and 404 Page Background.
	$page_classes = array(
		'.single_post',
		'.page .article',
		'.error404 .article',
	);

	$css['global'][ outspoken_implode( $page_classes ) ] = Outspoken_Sanitize::background( outspoken_get_settings( 'single_background' ) );

	// Margin, Padding, Border and Box Shadow.
	outspoken_merge_value( $css['global']['.article'], Outspoken_Sanitize::margin( outspoken_get_settings( 'mts_single_styling_margin' ) ) );
	outspoken_merge_value( $css['global'][ outspoken_implode( $page_classes ) ], Outspoken_Sanitize::padding( outspoken_get_settings( 'mts_single_styling_padding' ) ) );

	// Single border.
	$single_border = Outspoken_Sanitize::border( outspoken_get_settings( 'single_styling_border' ) );
	$css['global']['.article'][ $single_border ['direction'] ] = $single_border ['value'];

	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'single_post_categories_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'mts_single_meta_info_font' ) ) );

	// Tags.
	$css['global']['.tags a, .tagcloud a, .widget .wpt_widget_content #tags-tab-content ul li a']['background-color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'tags_bgcolor' ) );

	// Author Posts.
	$css['global']['.single-author-posts'] = Outspoken_Sanitize::background( outspoken_get_settings( 'authorpost_background' ) );

	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'authorpost_title_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'authorpost_categories_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'authorpost_meta_font' ) ) );

	outspoken_merge_value( $css['global']['.single-author-posts'], Outspoken_Sanitize::margin( outspoken_get_settings( 'authorpost_margin' ) ) );
	outspoken_merge_value( $css['global']['.single-author-posts'], Outspoken_Sanitize::padding( outspoken_get_settings( 'authorpost_padding' ) ) );

	// Related Posts.
	$css['global']['.related-posts'] = Outspoken_Sanitize::background( outspoken_get_settings( 'related_posts_background' ) );

	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'related_posts_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'related_posts_categories_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'related_posts_meta_font' ) ) );

	outspoken_merge_value( $css['global']['.related-posts'], Outspoken_Sanitize::margin( outspoken_get_settings( 'related_posts_margin' ) ) );
	outspoken_merge_value( $css['global']['.related-posts'], Outspoken_Sanitize::padding( outspoken_get_settings( 'related_posts_padding' ) ) );

	$related_posts_border = Outspoken_Sanitize::border( outspoken_get_settings( 'related_posts_border' ) );
	$css['global']['.related-posts'][ $related_posts_border ['direction'] ] = $related_posts_border ['value'];

	// Related Posts articles.
	$css['global']['.related-posts article'] = Outspoken_Sanitize::background( outspoken_get_settings( 'related_article_background' ) );
	outspoken_merge_value( $css['global']['.related-posts article'], Outspoken_Sanitize::padding( outspoken_get_settings( 'related_article_padding' ) ) );
	outspoken_merge_value( $css['global']['.related-posts article header'], Outspoken_Sanitize::padding( outspoken_get_settings( 'related_article_text_padding' ) ) );

	// Subscribe Box.
	$css['global']['.single-subscribe .widget.wp_subscribe'] = Outspoken_Sanitize::background( outspoken_get_settings( 'single_subscribe_background' ) );
	outspoken_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Outspoken_Sanitize::margin( outspoken_get_settings( 'single_subscribe_margin' ) ) );
	outspoken_merge_value( $css['global']['.single-subscribe .widget.wp_subscribe'], Outspoken_Sanitize::padding( outspoken_get_settings( 'single_subscribe_padding' ) ) );
	$css['global']['.single-subscribe .widget.wp_subscribe']['border-radius'] = Outspoken_Sanitize::size( outspoken_get_settings( 'single_subscribe_border_radius' ) . 'px' );

	// Subscribe border.
	$subscribe_border = Outspoken_Sanitize::border( outspoken_get_settings( 'single_subscribe_border' ) );
	$css['global']['.single-subscribe .widget.wp_subscribe'][ $subscribe_border ['direction'] ] = $subscribe_border ['value'];

	// Subscribe Box Input fields.
	$subscribe_input_class = array(
		'.single-subscribe #wp-subscribe input.email-field',
		'.single-subscribe #wp-subscribe input.name-field',
	);
	$css['global'][ outspoken_implode( $subscribe_input_class ) ]['background-color'] = Outspoken_Sanitize::color( outspoken_get_settings( 'single_subscribe_input_background' ) );

	$css['global'][ outspoken_implode( $subscribe_input_class ) ]['height'] = Outspoken_Sanitize::size( outspoken_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['height'] = Outspoken_Sanitize::size( outspoken_get_settings( 'single_subscribe_input_height' ) . 'px' );

	$css['global'][ outspoken_implode( $subscribe_input_class ) ]['border-radius'] = Outspoken_Sanitize::size( outspoken_get_settings( 'single_subscribe_input_border_radius' ) . 'px' );

	// Subscribe Box Input border.
	$subscribe_box_input_border = Outspoken_Sanitize::border( outspoken_get_settings( 'single_subscribe_input_border' ) );
	$css['global'][ outspoken_implode( $subscribe_input_class ) ][ $subscribe_box_input_border ['direction'] ] = $subscribe_box_input_border ['value'];

	// Subscribe Box Submit button.
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['background']    = Outspoken_Sanitize::color( outspoken_get_settings( 'single_subscribe_submit_backgroud' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit']['border-radius'] = Outspoken_Sanitize::size( outspoken_get_settings( 'single_subscribe_submit_border_radius' ) . 'px' );

	// Subscribe Box Submit border.
	$subscribe_box_submit_border = Outspoken_Sanitize::border( outspoken_get_settings( 'single_subscribe_submit_border' ) );
	$css['global']['.single-subscribe .widget #wp-subscribe input.submit'][ $subscribe_box_submit_border ['direction'] ] = $subscribe_box_submit_border ['value'];

	outspoken_merge_value( $css['global']['.single-subscribe .widget #wp-subscribe input.submit'], Outspoken_Sanitize::padding( outspoken_get_settings( 'single_subscribe_submit_padding' ) ) );

	// Author Box.
	$css['global']['.postauthor'] = Outspoken_Sanitize::background( outspoken_get_settings( 'authorbox_background' ) );

	outspoken_merge_value( $css['global']['.postauthor'], Outspoken_Sanitize::margin( outspoken_get_settings( 'authorbox_margin' ) ) );

	outspoken_merge_value( $css['global']['.postauthor'], Outspoken_Sanitize::padding( outspoken_get_settings( 'authorbox_padding' ) ) );

	$css['global']['.postauthor']['border-radius'] = Outspoken_Sanitize::size( outspoken_get_settings( 'authorbox_border_radius' ) . 'px' );

	$authorbox_border = Outspoken_Sanitize::border( outspoken_get_settings( 'authorbox_border' ) );
	$css['global']['.postauthor'][ $authorbox_border ['direction'] ] = $authorbox_border ['value'];

	// Author image.
	outspoken_merge_value( $css['global']['.postauthor img'], Outspoken_Sanitize::margin( outspoken_get_settings( 'single_author_image_margin' ) ) );

	$css['global']['.postauthor img']['border-radius'] = Outspoken_Sanitize::size( outspoken_get_settings( 'single_author_image_border_radius' ) . 'px' );

	// Single Page titles Styling.
	$titles_align = outspoken_get_settings( 'single_title_alignment' );

	$titles_align_class = array(
		'.comment-title',
		'#respond',
		'.related-posts-title',
	);
	$titles_class       = array(
		'#respond h4',
		'.total-comments',
		'.related-posts h4',
	);

	$css['global'][ outspoken_implode( $titles_class ) ] = Outspoken_Sanitize::background( outspoken_get_settings( 'single_title_background' ) );
	outspoken_merge_value( $css['global'][ outspoken_implode( $titles_class ) ], Outspoken_Sanitize::padding( outspoken_get_settings( 'single_title_padding' ) ) );
	// Single title border.
	$single_titles_border = Outspoken_Sanitize::border( outspoken_get_settings( 'single_title_border' ) );
	$css['global'][ outspoken_implode( $titles_class ) ][ $single_titles_border ['direction'] ] = $single_titles_border ['value'];

	if ( 'left' === $titles_align ) :
		$css['global'][ outspoken_implode( $titles_class ) ]['display'] = 'inline-block';
	elseif ( 'center' === $titles_align ) :
		$css['global'][ outspoken_implode( $titles_align_class ) ]['text-align'] = 'center';
		$css['global'][ outspoken_implode( $titles_class ) ]['display']          = 'inline-block';
	elseif ( 'right' === $titles_align ) :
		$css['global'][ outspoken_implode( $titles_align_class ) ]['text-align'] = 'right';
		$css['global'][ outspoken_implode( $titles_class ) ]['display']          = 'inline-block';
	endif;

}

/**
 * Copyrights
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_copyrights( &$css ) {

	// copyrights border.
	$copyrights_border = Outspoken_Sanitize::border( outspoken_get_settings( 'copyrights_border' ) );
	$css['global']['.copyrights'][ $copyrights_border ['direction'] ] = $copyrights_border ['value'];

}

/**
 * Footer
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_footer( &$css ) {

	// Footer.
	if ( outspoken_get_settings( 'mts_top_footer' ) ) {
		outspoken_merge_value( $css['global']['#site-footer'], Outspoken_Sanitize::margin( outspoken_get_settings( 'mts_top_footer_margin' ) ) );
		outspoken_merge_value( $css['global']['#site-footer'], Outspoken_Sanitize::padding( outspoken_get_settings( 'mts_top_footer_padding' ) ) );
	}

}

/**
 * Archive
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_archive_post( &$css ) {

	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'archive_post_title_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'archive_post_excerpt_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'archive_categories_font' ) ) );
	outspoken_map_css_selectors( $css['global'], Outspoken_Sanitize::typography( outspoken_get_settings( 'archive_meta_info_font' ) ) );

}

/**
 * Misc
 *
 * @param array $css Array of dynamic CSS.
 */
function outspoken_misc_css( &$css ) {

	// Nav hover color position.
	$padding        = Outspoken_Sanitize::padding( outspoken_get_settings( 'header_padding' ) );
	$padding_bottom = (int) $padding['padding-bottom'];

	// Show Logo.
	$show_logo = outspoken_get_settings( 'hide_logo' );

	if ( 0 === $show_logo ) {
		$css['global']['.logo-wrap']['display'] = 'none';
	}

	// Back to top.
	// Border.
	$top_button_border = Outspoken_Sanitize::border( outspoken_get_settings( 'top_button_border' ) );
	$css['global']['#move-to-top'][ $top_button_border ['direction'] ] = $top_button_border ['value'];
	// Font-size, Padding and Position.
	$css['global']['#move-to-top .fa']['font-size'] = Outspoken_Sanitize::size( outspoken_get_settings( 'top_button_font_size' ) . 'px' );
	outspoken_merge_value( $css['global']['#move-to-top'], Outspoken_Sanitize::padding( outspoken_get_settings( 'top_button_padding' ) ) );
	$top_button_position = outspoken_get_settings( 'top_button_position' );
	foreach ( $top_button_position as $key => $position ) {
		$css['global']['#move-to-top'][ $key ] = $position;
	}
	// Border-radius.
	$css['global']['#move-to-top']['border-radius'] = Outspoken_Sanitize::size( outspoken_get_settings( 'top_button_border_radius' ) . 'px' );
	// Colors.
	$css['global']['#move-to-top']['color']            = Outspoken_Sanitize::color( outspoken_get_settings( 'top_button_color' ) );
	$css['global']['#move-to-top:hover']['color']      = Outspoken_Sanitize::color( outspoken_get_settings( 'top_button_color_hover' ) );
	$css['global']['#move-to-top']['background']       = Outspoken_Sanitize::color( outspoken_get_settings( 'top_button_background' ) );
	$css['global']['#move-to-top:hover']['background'] = Outspoken_Sanitize::color( outspoken_get_settings( 'top_button_background_hover' ) );

	// Full width Related Posts.
	if ( 'full' === outspoken_get_settings( 'related_posts_position' ) ) {
		$css['global']['.single .article']['margin-bottom'] = '0px';
	}

}
